# eric7.Plugins.VcsPlugins.vcsMercurial.HisteditExtension.HgHisteditCommitEditor

Module implementing a dialog to edit the commit message of a revision.

### Global Attributes

None

### Classes

HgHisteditCommitEditor | Class implementing a dialog to edit the commit message of a revision.

### Functions

None

## HgHisteditCommitEditor

Class implementing a dialog to edit the commit message of a revision.

### Derived from

QDialog, Ui_HgHisteditCommitEditor

### Class Attributes

None

### Class Methods

None

### Methods

HgHisteditCommitEditor | Constructor
__readFile | Private method to read the file containing the commit message and populate the dialog.
on_buttonBox_accepted | Private slot called by the buttonBox accepted signal.
on_buttonBox_rejected | Private slot called by the buttonBox rejected signal.
on_recentComboBox_activated | Private slot to select a commit message from recent ones.

### Static Methods

None

#### HgHisteditCommitEditor (Constructor)

HgHisteditCommitEditor(fileName, parent=None)

Constructor

fileName (str)
  name of the file containing the commit message to be edited
parent (QWidget)
  reference to the parent widget

#### HgHisteditCommitEditor.__readFile

__readFile()

Private method to read the file containing the commit message and populate the dialog.

#### HgHisteditCommitEditor.on_buttonBox_accepted

on_buttonBox_accepted()

Private slot called by the buttonBox accepted signal.

#### HgHisteditCommitEditor.on_buttonBox_rejected

on_buttonBox_rejected()

Private slot called by the buttonBox rejected signal.

#### HgHisteditCommitEditor.on_recentComboBox_activated

on_recentComboBox_activated(index)

Private slot to select a commit message from recent ones.

index (int)
  index of the selected entry

Up